@@ -4,6 +4,7 @@ from .calibration import *
 from .cl import *
 from .instrument import *
 from .acquisition import *
+from .mapmaking import *
 from .pointings import *
 
-__version__ = '3.1'
+__version__ = '3.2.4'
